@@ -3,7 +3,8 @@ Encoding.default_external = Encoding::UTF_8
 require 'shellwords'
 
 require 'debci/config'
-require 'debci/blacklist'
+require 'debci/reject_list'
+require 'debci/extra_apt_sources_list'
 
 module Debci
   class CommandFailed < RuntimeError
@@ -14,8 +15,12 @@ module Debci
       @config ||= Debci::Config.new
     end
 
-    def blacklist
-      @blacklist ||= Debci::Blacklist.new
+    def reject_list
+      @reject_list ||= Debci::RejectList.new
+    end
+
+    def extra_apt_sources_list
+      @extra_apt_sources_list ||= Debci::ExtraAptSourcesList.new(File.join(Debci.config.config_dir, 'extra_apt_sources_list.yaml'))
     end
 
     def config!(data)
@@ -23,7 +28,8 @@ module Debci
         ENV["debci_#{k}"] = v
       end
       @config = nil
-      @blacklist = nil
+      @reject_list = nil
+      @extra_apt_sources_list = nil
     end
 
     def log(*str)
