@@ -71,7 +71,7 @@ module Debci
     end
 
     get '/auth/failure' do
-      halt(403, erb("<h2>Authentication Failed</h2><h4>Reason: </h4><pre>#{params[:message]}</pre>"))
+      halt(403, erb("<h2>Authentication Failed</h2><h4>Reason: </h4><pre><%= params[:message] %></pre>"))
     end
 
     get '/logout' do
@@ -218,7 +218,7 @@ module Debci
       query[:is_private] = is_private_filter unless is_private_filter.nil?
       query[:arch] = arch_filter if arch_filter
       query[:suite] = suite_filter if suite_filter
-      @history = Debci::Job.where(query)
+      @history = Debci::Job.where(query).includes([:package])
 
       unless package_filter.empty?
         pkgs = Debci::Package.where('name LIKE :query', query: package_filter.tr('*', '%')).pluck(:id)
@@ -250,7 +250,8 @@ module Debci
 
     post '/:user/test/publish' do
       run_ids = (params[:run_ids] || []).split(',')
-      Debci::Job.where(requestor: @user, run_id: run_ids).update(is_private: false)
+      jobs = Debci::Job.where(requestor: @user, run_id: run_ids)
+      jobs.update_all(is_private: false)
       @success = true
       [200, erb(:publish)]
     end
