@@ -636,6 +636,11 @@ describe Debci::SelfService do
       expect(last_response.status).to eq(302)
       expect(last_response.location).to match(%r{/user/auth/failure})
     end
+
+    it 'escapes message param on auth failure page' do
+      get '/user/auth/failure', message: "<svg onload=prompt('xxs')>"
+      expect(last_response.body).to_not match(/<svg/)
+    end
   end
 
   context 'publishing private tests' do
