@@ -23,6 +23,21 @@ require 'yaml'
 ENV['DATABASE_URL'] ||= 'sqlite3::memory:'
 require 'debci/db'
 require 'debci/job'
+require 'debci/app'
+
+if Gem::Specification.find_by_name("bullet").version >= Gem::Version.new("7")
+  require 'bullet'
+  module Debci
+    class App
+      configure do
+        Bullet.enable = true
+        Bullet.bullet_logger = true
+        Bullet.raise = true
+        use Bullet::Rack
+      end
+    end
+  end
+end
 
 require 'database_cleaner'
 require 'omniauth'
